@@ -15,8 +15,8 @@ from reV.econ.cli_econ import from_config as run_econ_from_config
 from reV.econ.cli_econ import valid_config_keys as econ_keys
 from reV.generation.cli_gen import from_config as run_gen_from_config
 from reV.generation.cli_gen import valid_config_keys as gen_keys
-from reV.offshore.cli_offshore import from_config as run_offshore_from_config
-from reV.offshore.cli_offshore import valid_config_keys as offshore_keys
+from reV.nrwal.cli_nrwal import from_config as run_nrwal_from_config
+from reV.nrwal.cli_nrwal import valid_config_keys as nrwal_keys
 from reV.pipeline.cli_pipeline import from_config as run_pipeline_from_config
 from reV.pipeline.cli_pipeline import valid_config_keys as pipeline_keys
 from reV.rep_profiles.cli_rep_profiles import from_config as run_rp_from_config
@@ -103,22 +103,22 @@ def valid_econ_keys(ctx):
 @click.option('-v', '--verbose', is_flag=True,
               help='Flag to turn on debug logging.')
 @click.pass_context
-def offshore(ctx, verbose):
-    """Offshore gen/econ aggregation with NRWAL."""
+def nrwal(ctx, verbose):
+    """Generic reV-NRWAL analysis."""
     if ctx.invoked_subcommand is None:
         config_file = ctx.obj['CONFIG_FILE']
         verbose = any([verbose, ctx.obj['VERBOSE']])
-        ctx.invoke(run_offshore_from_config, config_file=config_file,
+        ctx.invoke(run_nrwal_from_config, config_file=config_file,
                    verbose=verbose)
 
 
-@offshore.command()
+@nrwal.command()
 @click.pass_context
-def valid_offshore_keys(ctx):
+def valid_nrwal_keys(ctx):
     """
-    Valid offshore config keys
+    Valid nrwal config keys
     """
-    ctx.invoke(offshore_keys)
+    ctx.invoke(nrwal_keys)
 
 
 @main.group(invoke_without_command=True)
