@@ -143,7 +143,8 @@ def from_config(ctx, config_file, verbose):
                        walltime=config.execution_control.walltime,
                        feature=config.execution_control.feature,
                        conda_env=config.execution_control.conda_env,
-                       module=config.execution_control.module)
+                       module=config.execution_control.module,
+                       sh_script=config.execution_control.sh_script)
 
 
 @main.group(invoke_without_command=True)
@@ -295,9 +296,12 @@ def get_node_cmd(name, gen_fpath, rev_summary, reg_cols, cf_dset, rep_method,
 @click.option('--stdout_path', '-sout', default=None, type=STR,
               show_default=True,
               help='Subprocess standard output path. Default is in out_dir.')
+@click.option('--sh_script', '-sh', default=None, type=STR,
+              show_default=True,
+              help='Extra shell script commands to run before the reV call.')
 @click.pass_context
 def slurm(ctx, alloc, memory, walltime, feature, conda_env, module,
-          stdout_path):
+          stdout_path, sh_script):
     """slurm (Eagle) submission tool for reV representative profiles."""
 
     name = ctx.obj['NAME']
@@ -323,6 +327,9 @@ def slurm(ctx, alloc, memory, walltime, feature, conda_env, module,
                        out_dir, log_dir, max_workers, aggregate_profiles,
                        verbose)
 
+    if sh_script:
+        cmd = sh_script + '\n' + cmd
+
     slurm_manager = ctx.obj.get('SLURM_MANAGER', None)
     if slurm_manager is None:
         slurm_manager = SLURM()
